# Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added       
- Add repository URL to pyproject.toml
- Add GitHub Actions workflow for MkDocs deployment

### Changed     
- Updated the package structure based on the course code from the WQU. The 'pricing' module is now a called as 'dp' indicating its direct connection with the Derivative Pricing module.
- Update GitHub Actions workflow to trigger on changes in docs and mkdocs.yml
